==> jc-1.4.0.tar.gz: java/util/IdentityHashMap__24IdentityEntry.h <==
// final class java.util.IdentityHashMap$IdentityEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c47e8c79a0305079 java_util_IdentityHashMap__24IdentityEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_IdentityHashMap__24IdentityEntry_H_
#define _JC_java_util_IdentityHashMap__24IdentityEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_IdentityHashMap$object;

// Typedefs
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$sub_refs	_jc_java_util_IdentityHashMap__24IdentityEntry$sub_refs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$sub_nonrefs	_jc_java_util_IdentityHashMap__24IdentityEntry$sub_nonrefs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$refs	_jc_java_util_IdentityHashMap__24IdentityEntry$refs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$nonrefs	_jc_java_util_IdentityHashMap__24IdentityEntry$nonrefs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$object	_jc_java_util_IdentityHashMap__24IdentityEntry$object;

typedef const struct _jc_java_util_IdentityHashMap__24IdentityEntry$vmethods	_jc_java_util_IdentityHashMap__24IdentityEntry$vmethods;
typedef const struct _jc_java_util_IdentityHashMap__24IdentityEntry$vtable	_jc_java_util_IdentityHashMap__24IdentityEntry$vtable;
typedef const struct _jc_java_util_IdentityHashMap__24IdentityEntry$vtype	_jc_java_util_IdentityHashMap__24IdentityEntry$vtype;

// Constructors
extern void _jc_java_util_IdentityHashMap__24IdentityEntry$method$_init$ff992f6c22a57c02(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_util_IdentityHashMap$object *, jint);

// Virtual methods
extern jboolean _jc_java_util_IdentityHashMap__24IdentityEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_IdentityHashMap__24IdentityEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_IdentityHashMap__24IdentityEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
extern jint _jc_java_util_IdentityHashMap__24IdentityEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_IdentityHashMap__24IdentityEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_util_IdentityHashMap__24IdentityEntry$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_IdentityHashMap__24IdentityEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_IdentityHashMap__24IdentityEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_lang_Object$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *);
};

// Vtable
struct _jc_java_util_IdentityHashMap__24IdentityEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_IdentityHashMap__24IdentityEntry$vmethods	java_util_IdentityHashMap__24IdentityEntry;
};

// Vtype
struct _jc_java_util_IdentityHashMap__24IdentityEntry$vtype {
	_jc_type			type;
	_jc_java_util_IdentityHashMap__24IdentityEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_IdentityHashMap__24IdentityEntry$sub_refs {
	struct _jc_java_util_IdentityHashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_IdentityHashMap__24IdentityEntry$refs {
    _jc_java_util_IdentityHashMap__24IdentityEntry$sub_refs	java_util_IdentityHashMap__24IdentityEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_IdentityHashMap__24IdentityEntry$sub_nonrefs {
	jint	loc;
	jint	knownMod;
};

// Non-reference instance fields (object)
struct _jc_java_util_IdentityHashMap__24IdentityEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_IdentityHashMap__24IdentityEntry$sub_nonrefs	java_util_IdentityHashMap__24IdentityEntry;
};

// Object instance structure
struct _jc_java_util_IdentityHashMap__24IdentityEntry$object {
	_jc_java_util_IdentityHashMap__24IdentityEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_IdentityHashMap__24IdentityEntry$vtype	*vtype;
	_jc_java_util_IdentityHashMap__24IdentityEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_IdentityHashMap__24IdentityEntry$vtype _jc_java_util_IdentityHashMap__24IdentityEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_IdentityHashMap__24IdentityEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_IdentityHashMap__24IdentityEntry$class_object;

#endif	/* _JC_java_util_IdentityHashMap__24IdentityEntry_H_ */

==> jc-1.4.6.tar.gz: java/util/IdentityHashMap__24IdentityEntry.h <==
// final class java.util.IdentityHashMap$IdentityEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c47e8c79a0305079 java_util_IdentityHashMap__24IdentityEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_IdentityHashMap__24IdentityEntry_H_
#define _JC_java_util_IdentityHashMap__24IdentityEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_IdentityHashMap$object;

// Typedefs
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$sub_refs	_jc_java_util_IdentityHashMap__24IdentityEntry$sub_refs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$sub_nonrefs	_jc_java_util_IdentityHashMap__24IdentityEntry$sub_nonrefs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$refs	_jc_java_util_IdentityHashMap__24IdentityEntry$refs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$nonrefs	_jc_java_util_IdentityHashMap__24IdentityEntry$nonrefs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityEntry$object	_jc_java_util_IdentityHashMap__24IdentityEntry$object;

typedef const struct _jc_java_util_IdentityHashMap__24IdentityEntry$vmethods	_jc_java_util_IdentityHashMap__24IdentityEntry$vmethods;
typedef const struct _jc_java_util_IdentityHashMap__24IdentityEntry$vtable	_jc_java_util_IdentityHashMap__24IdentityEntry$vtable;
typedef const struct _jc_java_util_IdentityHashMap__24IdentityEntry$vtype	_jc_java_util_IdentityHashMap__24IdentityEntry$vtype;

// Constructors
extern void _jc_java_util_IdentityHashMap__24IdentityEntry$method$_init$ff992f6c22a57c02(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_util_IdentityHashMap$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_IdentityHashMap__24IdentityEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_IdentityHashMap__24IdentityEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_IdentityHashMap__24IdentityEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_IdentityHashMap__24IdentityEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_IdentityHashMap__24IdentityEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_IdentityHashMap__24IdentityEntry$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_IdentityHashMap__24IdentityEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_IdentityHashMap__24IdentityEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_IdentityHashMap__24IdentityEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_IdentityHashMap__24IdentityEntry$vmethods	java_util_IdentityHashMap__24IdentityEntry;
};

// Vtype
struct _jc_java_util_IdentityHashMap__24IdentityEntry$vtype {
	_jc_type			type;
	_jc_java_util_IdentityHashMap__24IdentityEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_IdentityHashMap__24IdentityEntry$sub_refs {
	struct _jc_java_util_IdentityHashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_IdentityHashMap__24IdentityEntry$refs {
    _jc_java_util_IdentityHashMap__24IdentityEntry$sub_refs	java_util_IdentityHashMap__24IdentityEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_IdentityHashMap__24IdentityEntry$sub_nonrefs {
	jint	loc;
	jint	knownMod;
};

// Non-reference instance fields (object)
struct _jc_java_util_IdentityHashMap__24IdentityEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_IdentityHashMap__24IdentityEntry$sub_nonrefs	java_util_IdentityHashMap__24IdentityEntry;
};

// Object instance structure
struct _jc_java_util_IdentityHashMap__24IdentityEntry$object {
	_jc_java_util_IdentityHashMap__24IdentityEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_IdentityHashMap__24IdentityEntry$vtype	*vtype;
	_jc_java_util_IdentityHashMap__24IdentityEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_IdentityHashMap__24IdentityEntry$vtype _jc_java_util_IdentityHashMap__24IdentityEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_IdentityHashMap__24IdentityEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_IdentityHashMap__24IdentityEntry$class_object;

#endif	/* _JC_java_util_IdentityHashMap__24IdentityEntry_H_ */
